
### Fixed
- Restore live_in_progress sum and use validated_live in progress output
- Show live validated_instances by summing in-progress processedCount

### Changed
- Split config and deployment into separate repo